@@ -1,12 +1,9 @@
 /* Handle conversion from Decimal32 to binary long double (128)
 
-   Copyright (C) 2007, 2008 IBM Corporation.
-   Copyright (C) 2008-2015 Free Software Foundation, Inc.
+   Copyright (C) 2016 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
-   Author(s): Pete Eberlein <eberlein@us.ibm.com>
-
    The Decimal Floating Point C Library is free software; you can
    redistribute it and/or modify it under the terms of the GNU Lesser
    General Public License version 2.1.
@@ -18,30 +15,43 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #ifndef DECIMAL_TO_BINARY
-#define DECIMAL_TO_BINARY
-#define SRC 32
-#define DEST 128
-#define NAME extend
+# define DECIMAL_TO_BINARY
+# define SRC 32
+# define DEST 128
+# define NAME extend
+# include "decimal32.h"
 #endif
 
 #include "dfpacc.h"
 #include "convert.h"
+#include <stdio.h>
 
-CONVERT_WRAPPER(
-	volatile double df_part1, df_part2;
-	_Decimal32 sd_part1, sd_part2;
+#define CONTEXT_INIT PASTE(DEC_INIT_DECIMAL,DEST)
 
-	df_part1 = a;			/* TD -> DF  */
-	sd_part1 = df_part1;		/* DF -> SD (not exact) */
-	sd_part2 = a - sd_part1;	/* SD */
-	df_part2 = sd_part2;		/* SD -> DF (trunc) */
-	result = df_part1;
-	result += df_part2;
-)
+#define BUFMAX 128
+
+DEST_TYPE
+PREFIXED_FUNCTION_NAME (SRC_TYPE a)
+{
+  /* decNumber's decimal* types have the same format as C's _Decimal*
+     types, but they have different calling conventions.  */
+  char buf[BUFMAX];
+  decNumber n;
+  decContext context;
+
+  decContextDefault (&context, CONTEXT_INIT);
+
+  PASTE(decimal,PASTE(SRC,ToNumber))((IEEE_SRC_TYPE*)&a, &n);
+
+  decNumberToString (&n, buf);
+
+  /* Use a C library function to convert to the integral type.  */
+  return strtold (buf, NULL);
+}
 hidden_def (PREFIXED_FUNCTION_NAME)
