@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -27,6 +27,6 @@
 unsigned long long
 __BACKEND_(fixunssddi) (_Decimal32 x)
 {
-  return (unsigned long long)((_Decimal64)x);
+  return (unsigned long long)(x);
 }
 hidden_def (__BACKEND_(fixunssddi))
