@@ -17,12 +17,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see dfp/COPYING.txt for more information.  */
 
 #define FUNC floattidd
 #define RET_TYPE _Decimal64
 #define RET_SIZE 64
-#include "floattitd.c"
+#include <floattitd.c>
