@@ -1,6 +1,6 @@
 /* Decimal Floating Point function intended to override the libgcc version.
 
-   Copyright (C) 2009 Free Software Foundation, Inc.
+   Copyright (C) 2009-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -17,15 +17,17 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #include <dfpacc.h>
+#include <convert.h>
 
 _Decimal32
 __BACKEND_(trunctdsd2) (_Decimal128 x)
 {
   return (_Decimal32)x;
 }
+hidden_def (__BACKEND_(trunctdsd2))
