@@ -1,12 +1,9 @@
 /* Handle conversion from Decimal128 to binary long double (dual 64bit)
 
-   Copyright (C) 2007, 2008 IBM Corporation.
-   Copyright (C) 2008-2015 Free Software Foundation, Inc.
+   Copyright (C) 2016 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
-   Author(s): Pete Eberlein <eberlein@us.ibm.com>
-
    The Decimal Floating Point C Library is free software; you can
    redistribute it and/or modify it under the terms of the GNU Lesser
    General Public License version 2.1.
@@ -18,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -27,8 +24,6 @@
 #define SRC 128
 #define DEST 128
 #define NAME trunc
+#include "decimal128.h"
 
-extern double __trunctddf(_Decimal128);
-extern _Decimal128 __extenddftd(double);
-
-#include "extendddtf.c"
+#include "extendsdtf.c"
