@@ -1,12 +1,9 @@
 /* Handle conversion from binary long double (128) to Decimal32
 
-   Copyright (C) 2007, 2008 IBM Corporation.
-   Copyright (C) 2008-2015 Free Software Foundation, Inc.
+   Copyright (C) 2016 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
-   Author(s): Pete Eberlein <eberlein@us.ibm.com>
-
    The Decimal Floating Point C Library is free software; you can
    redistribute it and/or modify it under the terms of the GNU Lesser
    General Public License version 2.1.
@@ -18,37 +15,45 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #ifndef BINARY_TO_DECIMAL
-#define BINARY_TO_DECIMAL
-#define SRC 128
-#define DEST 32
-#define NAME trunc
+# define BINARY_TO_DECIMAL
+# define SRC 128
+# define DEST 32
+# define NAME trunc
+# include "decimal32.h"
 #endif
 
 #include "dfpacc.h"
 #include "convert.h"
+#include <stdio.h>
 
-CONVERT_WRAPPER(
-// truncdfsd, extenddfdd, extenddftd
-	DEST_TYPE temp;
-	union {
-		SRC_TYPE ld;
-		double d[2];
-	} ldd;
+#define CONTEXT_INIT PASTE(DEC_INIT_DECIMAL,DEST)
 
-	ldd.ld = a;
-	temp = ldd.d[0];
-	result = temp;
-	temp = ldd.d[1];
-	result += temp;
-	/* Clear inexact exception raised by DFP arithmetic.  */
-	if (DFP_EXCEPTIONS_ENABLED
-	    && DFP_TEST_EXCEPTIONS (FE_OVERFLOW|FE_UNDERFLOW) == 0)
-	  DFP_CLEAR_EXCEPTIONS (FE_INEXACT);
-)
+#define BUFMAX 128
+
+DEST_TYPE
+PREFIXED_FUNCTION_NAME (SRC_TYPE a)
+{
+  DEST_TYPE f;
+  char buf[BUFMAX];
+  decContext context;
+
+  snprintf (buf, BUFMAX, "%.36Le", a);
+
+  decContextDefault (&context, CONTEXT_INIT);
+  PASTE(decimal,PASTE(DEST,FromString))((IEEE_DEST_TYPE*)&f, buf, &context);
+
+  if (context.status != 0) {
+    int dec_flags = context.status & 
+    (DEC_IEEE_854_Inexact|DEC_IEEE_854_Invalid_operation|DEC_IEEE_854_Overflow);
+    DFP_HANDLE_EXCEPTIONS(DFP_IEEE_FLAGS(dec_flags));
+  }
+
+  return f;
+}
 hidden_def (PREFIXED_FUNCTION_NAME)
