@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -29,5 +29,6 @@
 CMPINT
 __BACKEND_(unordsd2) (_Decimal32 x, _Decimal32 y)
 {
-  return __isnand64 ((_Decimal64)x) || __isnand64 ((_Decimal64)y);
+  return __builtin_isunordered (x, y);
 }
+hidden_def (__BACKEND_(unordsd2))
