@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -29,5 +29,6 @@
 CMPINT
 __BACKEND_(unordtd2) (_Decimal128 x, _Decimal128 y)
 {
-  return __isnand128 (x) || __isnand128 (y);
+  return __builtin_isunordered (x, y);
 }
+hidden_def (__BACKEND_(unordtd2))
