@@ -2,7 +2,7 @@
 
    Copyright (C) 1984, 1991 Stephen L. Moshier.
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2001, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2001-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -19,8 +19,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -103,7 +103,7 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x)
 
   z = x;
  /* extract power of 2, leaving mantissa between 0.5 and 1  */
-  x = FUNC_D(frexp) (x, &e);
+  x = FUNC_D(__frexp) (x, &e);
 
   /* Approximate cube root of number between .5 and 1,
      peak relative error = 1.2e-6  */
@@ -142,7 +142,7 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x)
     }
 
   /* multiply by power of 2 */
-  x = FUNC_D(ldexp) (x, e);
+  x = FUNC_D(__ldexp) (x, e);
 
   /* Newton iteration */
   x -= (x - (z / (x * x))) * 0.3333333333333333333333333333333333333333DL;
