@@ -19,8 +19,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -156,7 +156,6 @@ deval (_Decimal128 x, const _Decimal128 *p, int n)
 
 static const _Decimal128
 tiny = 1e-4931DL,
-  half = 0.5DL,
   one = 1.0DL,
   two = 2.0DL,
   /* 2/sqrt(pi) - 1 */
