@@ -1,7 +1,7 @@
 /* Calculate e^x, where x is the given _Decimal32 value
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -50,15 +50,15 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
   decNumber dn_x;
 
   FUNC_CONVERT_TO_DN(&x, &dn_x);
-  ___decContextDefault(&context, DEFAULT_CONTEXT);
-  if (___decNumberIsInfinite(&dn_x)) {
-    if (___decNumberIsNegative(&dn_x)) {
-      ___decNumberZero(&dn_result);	/* exp(-inf) = 0 */
+  decContextDefault(&context, DEFAULT_CONTEXT);
+  if (decNumberIsInfinite(&dn_x)) {
+    if (decNumberIsNegative(&dn_x)) {
+      decNumberZero(&dn_result);	/* exp(-inf) = 0 */
     } else {
       dn_result = dn_x;			/* exp(inf) = inf */
     }
   } else {
-    ___decNumberExp(&dn_result, &dn_x, &context);
+    decNumberExp(&dn_result, &dn_x, &context);
   }
 
   FUNC_CONVERT_FROM_DN(&dn_result, &result, &context);
