@@ -1,7 +1,7 @@
 /* Returns a value equivelent to exp(x) - 1
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -53,15 +53,15 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
 
   FUNC_CONVERT_TO_DN(&x, &dn_x);
   FUNC_CONVERT_TO_DN(&one, &dn_one);
-  if (___decNumberIsNaN (&dn_x))
+  if (decNumberIsNaN (&dn_x))
     return x+x;
 
-  if (___decNumberIsInfinite (&dn_x))
-    return ___decNumberIsNegative (&dn_x) ? DFP_CONSTANT(-1.0) : x;
+  if (decNumberIsInfinite (&dn_x))
+    return decNumberIsNegative (&dn_x) ? DFP_CONSTANT(-1.0) : x;
 
-  ___decContextDefault(&context, DEFAULT_CONTEXT);
-  ___decNumberExp(&dn_exponent, &dn_x, &context);
-  ___decNumberSubtract(&dn_result, &dn_exponent, &dn_one, &context);
+  decContextDefault(&context, DEFAULT_CONTEXT);
+  decNumberExp(&dn_exponent, &dn_x, &context);
+  decNumberSubtract(&dn_result, &dn_exponent, &dn_one, &context);
 
   FUNC_CONVERT_FROM_DN(&dn_result, &result, &context);
   if (context.status & DEC_Overflow)
