@@ -1,6 +1,6 @@
 /* Returns the unbiased exponent of the passed _Decimal32 value as an long int.
 
-   Copyright (C) 2014 Free Software Foundation, Inc.
+   Copyright (C) 2014-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -24,5 +24,7 @@
 #define FUNCTION_NAME  llogb
 #define _MAX_VALUE     LONG_MAX
 #define _MIN_VALUE     LONG_MIN
+#define _FBLOG0        FP_LLOGB0
+#define _FBLOGNAN      FP_LLOGBNAN
 
 #include "ilogbd32.c"
