@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -36,4 +36,13 @@
 #include <mapround.h>
 #define __ROUND_MODE __dn_getround()
 
+#define POSTFIX_CHECK					\
+  do							\
+    {							\
+      if (x != result)					\
+	{						\
+	  DFP_EXCEPT (FE_INEXACT);			\
+	}						\
+    } while (0)
+
 #include "llroundd32.c"
