@@ -1,4 +1,4 @@
-/* Returns a reprentation of NaN in the _Decimal128 format
+/* Returns a representation of NaN in the _Decimal128 format
 
    Copyright (C) 2006 IBM Corporation.
    Copyright (C) 2007-2015 Free Software Foundation, Inc.
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
