@@ -18,12 +18,13 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #define _DECIMAL_SIZE 128
 #include <decimal128.h>
-
+#define SUBNORMAL_MIN DEC128_SUBNORMAL_MIN
+#define DEC_MAX DEC128_MAX
 #include "nextafterd32.c"
