@@ -18,16 +18,14 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #define _DECIMAL_SIZE 64
-
-/* Always include this since we need a _Decimal128 converted to a decNumber */
+#define SUBNORMAL_MIN DEC64_SUBNORMAL_MIN
+#define DEC_MAX DEC64_MAX
 #include <decimal128.h>
-#include <dfptypeconv128.h>
 #include <decimal64.h>
-
 #include "nexttowardd32.c"
