@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -34,6 +34,7 @@
 #include <math.h>
 #include <fenv.h>
 #include <mapround.h>
+#include <ieee754r_private.h>
 
 #define FUNCTION_NAME quantize
 
@@ -60,4 +61,5 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
   return result;
 }
 
+hidden_def (INTERNAL_FUNCTION_NAME)
 weak_alias (INTERNAL_FUNCTION_NAME, EXTERNAL_FUNCTION_NAME)
