@@ -1,7 +1,7 @@
 /* Returns true if x and y have the same exponent
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -45,13 +45,13 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
   FUNC_CONVERT_TO_DN(&x, &dn_x);
   FUNC_CONVERT_TO_DN(&y, &dn_y);
 
-  if(___decNumberIsNaN(&dn_x) && ___decNumberIsNaN(&dn_y))
+  if(decNumberIsNaN(&dn_x) && decNumberIsNaN(&dn_y))
     return true;
-  if(___decNumberIsNaN(&dn_x) || ___decNumberIsNaN(&dn_y))
+  if(decNumberIsNaN(&dn_x) || decNumberIsNaN(&dn_y))
     return false;
-  if(___decNumberIsInfinite(&dn_x) && ___decNumberIsInfinite(&dn_y))
+  if(decNumberIsInfinite(&dn_x) && decNumberIsInfinite(&dn_y))
     return true;
-  if(___decNumberIsInfinite(&dn_x) || ___decNumberIsInfinite(&dn_y))
+  if(decNumberIsInfinite(&dn_x) || decNumberIsInfinite(&dn_y))
     return false;
 
   return (dn_x.exponent == dn_y.exponent);
