@@ -1,7 +1,7 @@
 /* Calculate the tan(x) for _Decimal32 format x
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -49,15 +49,15 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
   decNumber dn_x;
 
   FUNC_CONVERT_TO_DN (&x, &dn_x);
-  if (___decNumberIsNaN (&dn_x) || ___decNumberIsZero (&dn_x))
+  if (decNumberIsNaN (&dn_x) || decNumberIsZero (&dn_x))
     return x+x;
-  if (___decNumberIsInfinite (&dn_x))
+  if (decNumberIsInfinite (&dn_x))
     {
       DFP_EXCEPT (FE_INVALID);
       return DFP_NAN;
     }
-  ___decContextDefault (&context, DEFAULT_CONTEXT);
-  ___decNumberTan (&dn_result, &dn_x, &context);
+  decContextDefault (&context, DEFAULT_CONTEXT);
+  decNumberTan (&dn_result, &dn_x, &context);
 
   FUNC_CONVERT_FROM_DN (&dn_result, &result, &context);
   if (context.status & DEC_Overflow)
