@@ -1,7 +1,7 @@
 /* Returns the result of integral[0->inf, t**(x-1) * e**(-t) dt]
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -56,14 +56,14 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
 //      return FUNC_D (__builtin_signbit) (x) ? -DFP_HUGE_VAL : DFP_HUGE_VAL;
       return (x<0) ? -DFP_HUGE_VAL : DFP_HUGE_VAL;
     }
-  if (x < DFP_CONSTANT(0.0) && (!FUNC_D (__isinf) (x) && FUNC_D (rint) (x) == x) )
+  if (x < DFP_CONSTANT(0.0) && (!FUNC_D (__isinf) (x) && FUNC_D (__rint) (x) == x) )
     {
       DFP_EXCEPT (FE_INVALID);
       return DFP_NAN;
     }
 
   gamma = FUNC_D(__lgamma_r) (x,&local_signgam);
-  result = local_signgam * FUNC_D(exp) (gamma);
+  result = local_signgam * FUNC_D(__exp) (gamma);
 
   return result;
 }
@@ -75,7 +75,7 @@ INTERNAL_FUNCTION_NAME (DEC_TYPE x)
   DEC_TYPE z = IEEE_FUNCTION_NAME (x);
   if (!FUNC_D(__isfinite) (z) && FUNC_D(__isfinite) (x))
     DFP_ERRNO (ERANGE);
-  if (x < DFP_CONSTANT(0.0) && (FUNC_D (__isinf) (x) && FUNC_D (rint) (x) == x) )
+  if (x < DFP_CONSTANT(0.0) && (FUNC_D (__isinf) (x) && FUNC_D (__rint) (x) == x) )
     DFP_ERRNO (EDOM);
   return z;
 }
