@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see dfp/COPYING.txt for more information.  */
 
@@ -53,4 +53,9 @@ hidden_proto (__dfp_ais)
 extern int __register_printf_dfp (void);
 hidden_proto(__register_printf_dfp)
 
+/* Modifiers for re-using printf hook as strfromdN */
+extern int mod_H;
+extern int mod_D;
+extern int mod_DD;
+
 #endif
