@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -36,7 +36,7 @@ asm ("__dpd_floatunsditd  = __GI___dpd_floatditd");
 asm ("__dpd_floatunsdidd  = __GI___dpd_floatdidd");
 asm ("__dpd_floatunsdisd  = __GI___dpd_floatdisd");
 
-#ifdef HAVE_UINT128_T
+#ifdef __SIZEOF_INT128__
 asm ("__dpd_floattitd  = __GI___dpd_floattitd");
 
 asm ("__dpd_floatunstitd  = __GI___dpd_floatunstitd");
@@ -68,7 +68,7 @@ asm ("__dpd_fixunssddi = __GI___dpd_fixunssddi");
 asm ("__dpd_fixunsdddi = __GI___dpd_fixunsdddi");
 asm ("__dpd_fixunstddi = __GI___dpd_fixunstddi");
 
-#ifdef HAVE_UINT128_T
+#ifdef __SIZEOF_INT128__
 asm ("__dpd_fixtdti = __GI___dpd_fixtdti");
 
 asm ("__dpd_fixunstdti = __GI___dpd_fixunstdti");
@@ -99,18 +99,28 @@ asm ("__dpd_eqdd2 = __GI___dpd_eqdd2");
 asm ("__dpd_eqsd2 = __GI___dpd_eqsd2");
 asm ("__dpd_eqtd2 = __GI___dpd_eqtd2");
 
-asm ("__dpd_ltdd2 = __GI___dpd_ltdd2");
 asm ("__dpd_ltsd2 = __GI___dpd_ltsd2");
+asm ("__dpd_ltdd2 = __GI___dpd_ltdd2");
 asm ("__dpd_lttd2 = __GI___dpd_lttd2");
 
 asm ("__dpd_gtsd2 = __GI___dpd_gtsd2");
+asm ("__dpd_gtdd2 = __GI___dpd_gtdd2");
 asm ("__dpd_gttd2 = __GI___dpd_gttd2");
 
+asm ("__dpd_lesd2 = __GI___dpd_lesd2");
+asm ("__dpd_ledd2 = __GI___dpd_ledd2");
 asm ("__dpd_letd2 = __GI___dpd_letd2");
+
+asm ("__dpd_gesd2 = __GI___dpd_gesd2");
+asm ("__dpd_gedd2 = __GI___dpd_gedd2");
 asm ("__dpd_getd2 = __GI___dpd_getd2");
 
-asm ("__dpd_netd2 = __GI___dpd_netd2");
 asm ("__dpd_nesd2 = __GI___dpd_nesd2");
 asm ("__dpd_nedd2 = __GI___dpd_nedd2");
+asm ("__dpd_netd2 = __GI___dpd_netd2");
+
+asm ("__dpd_unordsd2 = __GI___dpd_unordsd2");
+asm ("__dpd_unorddd2 = __GI___dpd_unorddd2");
+asm ("__dpd_unordtd2 = __GI___dpd_unordtd2");
 
 #endif
