@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -24,13 +24,7 @@
 _Decimal128
 __fabsd128 (_Decimal128 x)
 {
-  /* Half part os decimal128 constainst the sign bit at same position as
-     binary64, so the instruction works for both formats.  */
-  _Decimal128 ret;
-  asm ("fabs  %0, %1\n"
-       : "=f"(ret)
-       : "f"(x));
-  return ret;
+  return __builtin_fabsd128 (x);
 }
 hidden_def (__fabsd128)
 weak_alias (__fabsd128, fabsd128)
