@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -24,14 +24,7 @@
 _Decimal32
 __fabsd32 (_Decimal32 x)
 {
-  /* Both binary32 and decimal32 have the sign bit at same position,
-     so the instruction works for both format.  */
-  _Decimal64 tmp;
-  asm ("dctdp %0, %1\n"  /* DFP Convert To DFP Long  */
-       "fabs  %0, %0\n"
-       : "=&f"(tmp)
-       : "f" (x));
-  return (_Decimal32)tmp;
+  return __builtin_fabsd32 (x);
 }
 hidden_def (__fabsd32)
 weak_alias (__fabsd32, fabsd32)
