@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -27,13 +27,12 @@
 int
 __isnand128 (_Decimal128 val)
 {
-  register _Decimal128 input asm("fr0") = val;
   int cr0;
 
   asm ("dtstdcq cr0,%1,3\n"
-       "mfcr     %0, 0\n"
+       "mfcr     %0, 128\n"
     : "=r" (cr0)
-    : "f" (input)
+    : "f" (val)
     : "cr0");
 
   return (cr0 & 0x20000000) ? 1 : 0;
