@@ -16,8 +16,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see dfp/COPYING.txt for more information.  */
 
@@ -30,7 +30,7 @@ __isnormald64 (_Decimal64 x)
   int cr0;
 
   asm ("dtstdc cr0,%1,0x08\n"
-       "mfcr   %0, 0\n"
+       "mfcr   %0, 128\n"
     : "=r" (cr0)
     : "f" (x)
     : "cr0");
