@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -30,7 +30,7 @@ __issignalingd32 (_Decimal32 x)
 
   /* DCM bit 5 is signaling NaN  */
   asm ("dtstdc cr0,%1,1\n"
-       "mfcr   %0, 0\n"
+       "mfcr   %0, 128\n"
        : "=r" (cr0)
        : "f" (input)
        : "cr0");
