@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -28,12 +28,11 @@ long long int
 __llquantexpd128 (_Decimal128 x)
 {
   long long int ret;
-  register _Decimal128 input asm("fr0") = x;
   _Decimal128 r;
   asm ("dxexq   %0,%1\n"
        "dcffixq %0,%0\n"
     : "=f"(r) :
-      "f"(input));
+      "f"(x));
   ret = (long long int)r;
   if ((ret == -1) ||  /* Infinity  */
       (ret == -2) ||  /* NaN  */
