@@ -15,22 +15,20 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #include <math.h>
 
+#include "dfp_inline.h"
+
+#undef __quantized128
+
 _Decimal128
 __quantized128(_Decimal128 x, _Decimal128 y)
 {
-  _Decimal128 result;
-
-  asm ("dquaq %0,%1,%2,3\n\t"
-	: "=f" (result)
-        : "f" (y), "f" (x));
-  return result;
-
+  return ___quantized128 (x, y);
 }
 weak_alias (__quantized128, quantized128)
