@@ -15,21 +15,20 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
 #include <math.h>
 
+#include "dfp_inline.h"
+
+#undef __quantized64
+
 _Decimal64
 __quantized64 (_Decimal64 x, _Decimal64 y)
 {
-  _Decimal64 result;
-
-  asm ("dqua %0,%1,%2,3;"
-	: "=f" (result)
-	: "f" (y), "f" (x));
-  return result;
+  return ___quantized64 (x, y);
 }
 weak_alias (__quantized64, quantized64)
