@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -25,13 +25,12 @@
 /* Return the quantum 1 * 10^exponent(x)  */
 _Decimal128 __quantumd128 (_Decimal128 x)
 {
-  register _Decimal128 input asm("fr0") = x;
   _Decimal128 ret;
   _Decimal128 ref = 1e-6176DL;
   asm ("dxexq   %1,%1\n"      /* Extract exponent  */
        "diexq   %0,%1,%2\n"   /* Sets it to reference value  */
     : "=d"(ret) :
-      "d"(input), "d"(ref));
+      "d"(x), "d"(ref));
   return ret;
 }
 weak_alias (__quantumd128, quantumd128)
