@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -24,11 +24,10 @@
 
 _Decimal128 __roundevend128 (_Decimal128 x)
 {
-  register _Decimal128 input asm("fr0") = x;
   _Decimal128 ret;
   asm ("drintnq 0,%0,%1,0\n"
     : "=f"(ret)
-    : "f"(input));
+    : "f"(x));
   return ret;
 }
 weak_alias (__roundevend128, roundevend128)
