@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -28,6 +28,7 @@
 # define FUNCTION_NAME islessgreater
 #endif
 #include <dfpmacro.h>
+#include <ieee754r_private.h>
 
 int
 INTERNAL_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
