@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -40,18 +40,14 @@ PREFIXED_FUNCTION_NAME (SRC_TYPE a)
 	DEST_TYPE result;
 	decNumber d;
 	decContext context;
-	IEEE_SRC_TYPE e;
-	IEEE_DEST_TYPE r;
 	
 	decContextDefault(&context, CONTEXT_INIT);
 	context.round = __dn_getround();
 	
-	PASTE(___host_to_ieee_,SRC) ((&a), &e);
-	PASTE(decimal,PASTE(SRC,ToNumber))(&e, &d);
+	PASTE(decimal,PASTE(SRC,ToNumber))((IEEE_SRC_TYPE*)&a, &d);
 	/* PASTE(___decimal,PASTE(SRC,ToNumber))(&a, &d); */
 	/* PASTE(___decimal,PASTE(DEST,FromNumber))(&result, &d, &context);  */
-	PASTE(decimal,PASTE(DEST,FromNumber))(&r, &d, &context);
-	PASTE(PASTE(___ieee_,DEST),_to_host) (&r, (&result));
+	PASTE(decimal,PASTE(DEST,FromNumber))((IEEE_DEST_TYPE*)&result, &d, &context);
 
 	if (context.status != 0) {
 	  int dec_flags = context.status & (DEC_IEEE_854_Inexact|DEC_IEEE_854_Invalid_operation);
