@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -50,15 +50,13 @@ PREFIXED_FUNCTION_NAME (SRC_TYPE a)
   char *pos;
   decNumber qval, n1, n2;
   decContext context;
-  IEEE_SRC_TYPE e;
 
   /* Use a large context to avoid losing precision.  */
   decContextDefault (&context, DEC_INIT_DECIMAL128);
   /* Need non-default rounding mode here.  */
   context.round = DEC_ROUND_DOWN;
 
-  PASTE(___host_to_ieee_,SRC) ((&a), &e);
-  PASTE(decimal,PASTE(SRC,ToNumber))(&e, &n1);
+  PASTE(decimal,PASTE(SRC,ToNumber))((IEEE_SRC_TYPE*)&a, &n1);
   /* PASTE(decimal,PASTE(SRC,ToNumber))(&a, &n1); */
 
   /* Rescale if the exponent is less than zero.  */
