@@ -18,8 +18,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -37,6 +37,7 @@
 
 #include "dfpacc.h"
 #include <dfpmacro.h>
+#include "mapround.h"
 DEC_TYPE
 PREFIXED_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 {
@@ -44,6 +45,7 @@ PREFIXED_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
   decNumber dn_x, dn_y, dn_result;
   decContext context;
   decContextDefault(&context, DEFAULT_CONTEXT);
+  context.round = __dn_getround();
 
   FUNC_CONVERT_TO_DN(&x, &dn_x);
   FUNC_CONVERT_TO_DN(&y, &dn_y);
