@@ -1,10 +1,17 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import sys
 import re
 import os
 from optparse import OptionParser
 
+# Use CPP flags to guard tests which should not be
+# be on certain platforms (e.g sizeof(long int) != x
+cppcheckdict = {
+    "ONLY_ON_4BYTE_LONG" : "(__SIZEOF_LONG__ == 4)",
+    "ONLY_ON_8BYTE_LONG" : "(__SIZEOF_LONG__ == 8)"
+    }
+
 # Decribes the evaluated function
 class Function:
   def __init__ (self):
@@ -38,6 +45,7 @@ class Operation:
     self.ret = None
     self.extraflags = []
     self.line = line
+    self.cppchecks = []
 
 # Describe a type handle in operations and functions definition
 class Type (object):
@@ -111,26 +119,26 @@ class DecimalType(Type):
     # Infinity
     if "Inf" in arg:
       prefix = "minus" if ("-" in arg) else "plus"
-      return "{ .%s = %s_infty }" % (DECIMAL.decfield, prefix)
+      return "{ .%s = %s_infty }" % (self.decfield, prefix)
     # Replace <number>E[+-]DEC_[MAX|MIN]_EXP by a expected number, i.e,
     # 1E-DEC_MIN_EXP -> 1E-383
     if "DEC_MAX_EXP" in arg:
-      arg = arg.replace ("DEC_MAX_EXP", DECIMAL.maxexp)
+      arg = arg.replace ("DEC_MAX_EXP", self.maxexp)
     if "DEC_MIN_EXP_SUB" in arg:
-      arg = arg.replace ("DEC_MIN_EXP_SUB", DECIMAL.minexpsub)
+      arg = arg.replace ("DEC_MIN_EXP_SUB", self.minexpsub)
     if "DEC_MIN_EXP" in arg:
-      arg = arg.replace ("DEC_MIN_EXP", DECIMAL.minexp)
+      arg = arg.replace ("DEC_MIN_EXP", self.minexp)
     # Macro fox max, min, tiny values
     if "DEC_MAX" in arg:
-      arg = arg.replace ("DEC_MAX", DECIMAL.maxvalue);
+      arg = arg.replace ("DEC_MAX", self.maxvalue);
     if "DEC_MIN" in arg:
-      arg = arg.replace ("DEC_MIN", DECIMAL.minvalue);
+      arg = arg.replace ("DEC_MIN", self.minvalue);
     if "DEC_SUBNORMAL_MIN" in arg:
-      arg = arg.replace ("DEC_SUBNORMAL_MIN", DECIMAL.subnormal);
+      arg = arg.replace ("DEC_SUBNORMAL_MIN", self.subnormal);
     # Normal value
     if not self.intnum_re.match (arg):
-      arg += DECIMAL.suffix
-    return "{ .%s = %s }" % (DECIMAL.decfield, arg)
+      arg += self.suffix
+    return "{ .%s = %s }" % (self.decfield, arg)
 
 
 DecimalTypes = {
@@ -218,7 +226,10 @@ def parse_file (filename):
     if fields[1].startswith("name"):
       func.name = fields[2]
     if fields[1].startswith("arg"):
-      func.args.append(DecimalTypes[fields[2] + DECIMAL.tname])
+      if fields[2] == "decimal":
+        func.args.append(DecimalTypes[fields[2] + DECIMAL.tname])
+      else:
+        func.args.append(DecimalTypes[fields[2]])
     elif fields[1].startswith("ret"):
       rettname = fields[2]
       if rettname == "decimal":
@@ -264,7 +275,19 @@ def parse_file (filename):
     for oparg in range (0, expected_args):
       op.args.append(fields[oparg])
     op.ret = fields[expected_args]
-    op.extraflags.extend(extra_args)
+
+    for earg in extra_args:
+      if earg in cppcheckdict.keys():
+        op.cppchecks.append(cppcheckdict[earg])
+      else:
+        op.extraflags.append(earg)
+
+    # Finally, if we ignore the results, coerce to a value
+    # which won't make the compiler generate warnings:
+    if "IGNORE_RESULT" in op.extraflags:
+      if op.ret != "0":
+        sys.stderr.write ("WARNING: ignored value coerced to 0 on line %d\n" % i)
+      op.ret = "0"
 
     operations.append(op)
 
@@ -323,17 +346,23 @@ def print_operations (func, operations):
   print ("")
   print ("static const operations_t operations[] = {")
   for op in operations:
-    print ("  {"),
-    print ("\"%s\", " % ", ".join(op.args)),
+    if op.cppchecks:
+        print ("#if " + " && ".join (op.cppchecks))
+    line = ""
+    line += "  {"
+    line += "\"%s\", " % ", ".join(op.args)
     for i in range(0, len(op.args)):
-      print ("%s," % func.args[i].parse_arg(op.args[i])),
-    print (" %s, " % func.ret.parse_arg(op.ret)),
+      line += "%s," % func.args[i].parse_arg(op.args[i])
+    line += " %s, " % func.ret.parse_arg(op.ret)
     if (len(op.extraflags) > 0):
-      print ("|".join (op.extraflags)),
-      print (", "),
+      line += "|".join (op.extraflags)
+      line += ", "
     else:
-      print ("NO_EXTRA_FLAG, "),
-    print (" %d }," % op.line)
+      line += "NO_EXTRA_FLAG, "
+    line += " %d }," % op.line
+    print (line)
+    if op.cppchecks:
+      print ("#endif")
   print ("};")
   print ("static const int operations_size = \
     sizeof(operations)/sizeof(operations[0]);");
@@ -341,8 +370,10 @@ def print_operations (func, operations):
 
 
 def print_func_call(func):
-  print ("int main (void) {")
+  print ("int main (int argn, char *argv[]) {")
   print ("  int i;")
+  print ("")
+  print ("  scaffold_setup (argn, argv, \"%s\");" % func.name)
   print ("  for (i = 0; i < operations_size; ++i) {")
 
   # <macro> (func.name, arg1, arg2, ..., ret, expected)
@@ -355,14 +386,23 @@ def print_func_call(func):
     "decimal64"  : "f",
     "decimal128" : "f"
   }
-  macro = "RUN_TEST_" + ('f' * len(func.args)) + "_" + MACROSUFFIX[func.ret.name]
-  
-  print ("    %s (%s, operations[i].argname, " % (macro, func.name, )),
+  macro = "RUN_TEST_";
+  for arg in func.args:
+    macro += MACROSUFFIX[arg.name]
+  macro += "_" + MACROSUFFIX[func.ret.name]
+
+  line = "    %s (%s, operations[i].argname, " % (macro, func.name, )
   for i in range(0, len(func.args)):
-    print ("operations[i].arg%i.%s, " % (i, DECIMAL.decfield)),
-  print ("operations[i].e%s, operations[i].extraflags);" % func.ret_field())
+    line += "operations[i].arg%i" % i
+    if "decimal" in func.args[i].name:
+      line += "." + func.args[i].decfield
+    line += ", "
+
+  line += "operations[i].e%s, operations[i].extraflags);" % func.ret_field()
+  print (line)
 
   print ("  }")
+  print ("  scaffold_teardown ();")
   print ("")
   print ("  return noErrors;");
   print ("}")
@@ -385,22 +425,16 @@ if __name__ == "__main__":
                      help="DECIMAL type to use")
   (options, args) = parser.parse_args()
 
-  try:
-    if options.filename:
-      sys.stdout = open (options.filename, "w")
+  if options.filename:
+    sys.stdout = open (options.filename, "w")
 
-    if not args:
-      sys.stderr.write ("usage: gen-libdfp-tests.py <options> <input file\n>")
-      raise Exception()
-    if not options.dectype:
-      sys.stderr.write ("error: you must specify a type: decimal[32|64|128]")
-      raise Exception()
+  if not args:
+    sys.stderr.write ("usage: gen-libdfp-tests.py <options> <input file\n>")
+    raise Exception()
+  if not options.dectype:
+    sys.stderr.write ("error: you must specify a type: decimal[32|64|128]")
+    raise Exception()
 
-    DECIMAL = DecimalTypes[options.dectype]
+  DECIMAL = DecimalTypes[options.dectype]
 
-    print_output (args[0])
-
-  except:
-    if options.filename:
-      os.remove (options.filename)
-    exit (1)
+  print_output (args[0])
