@@ -13,11 +13,15 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
+#include <getopt.h>
+#include <string.h>
+#include <error.h>
+
 /* Test flags (e.g. possible exceptions) */
 #define NO_EXTRA_FLAG			0x0
 #define INVALID_EXCEPTION		0x1
@@ -28,8 +32,6 @@
 #define ERRNO_UNCHANGED			0x8000
 #define ERRNO_ERANGE			0x20000
 #define IGNORE_RESULT			0x40000
-#define ONLY_ON_4BYTE_LONG		0x100000
-#define ONLY_ON_8BYTE_LONG		0x200000
 
 
 /* Common setup for an individual test.  */
@@ -44,20 +46,10 @@
 #define COMMON_TEST_CLEANUP                     \
   free (test_name)
 
-/* Skip test in case of invalid characteristics.  */
-#define CHECK_SKIP_TEST(EXTRAFLAGS)			\
-  if (((EXTRAFLAGS & ONLY_ON_4BYTE_LONG) != 0		\
-       && sizeof(long int) != 4)			\
-      || ((EXTRAFLAGS & ONLY_ON_8BYTE_LONG) != 0	\
-	  && sizeof(long int) != 8))			\
-    break;
-
-
 /* Run an individual test, including any required setup and checking
    of results, or loop over all tests in an array.  */
 #define RUN_TEST_f_f(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_float (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
 		EXTRAFLAGS);						\
@@ -66,7 +58,6 @@
 
 #define RUN_TEST_ff_f(FUNC_NAME, ARG_STR, ARG1, ARG2, EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_float (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
 		EXTRAFLAGS);						\
@@ -75,7 +66,6 @@
 
 #define RUN_TEST_f_i(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_int (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED, EXTRAFLAGS);	\
    COMMON_TEST_CLEANUP;                                                 \
@@ -83,7 +73,6 @@
 
 #define RUN_TEST_f_l(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_long (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
 	       EXTRAFLAGS);						\
@@ -92,7 +81,6 @@
 
 #define RUN_TEST_f_L(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_longlong (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
 		   EXTRAFLAGS);						\
@@ -101,7 +89,6 @@
 
 #define RUN_TEST_f_b(FUNC_NAME, ARG_STR, ARG1, EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_bool (test_name, FUNC (FUNC_NAME) (ARG1), EXPECTED,		\
 	       EXTRAFLAGS);						\
@@ -110,7 +97,6 @@
 
 #define RUN_TEST_ff_b(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_bool (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
 	       EXTRAFLAGS);						\
@@ -119,17 +105,36 @@
 
 #define RUN_TEST_ff_i(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
-   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
    check_int (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
 	      EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
+#define RUN_TEST_fi_f(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED, EXTRAFLAGS) \
+  do {                                                                  \
+   COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
+   check_float (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
+		EXTRAFLAGS);						\
+   COMMON_TEST_CLEANUP;                                                 \
+  } while (0)
+
 
 #define MANT_DIG CHOOSE ((DEC128_MANT_DIG-1), (DEC64_MANT_DIG-1), (DEC32_MANT_DIG-1))
 #define MIN_EXP CHOOSE ((DEC128_MIN_EXP-1), (DEC64_MIN_EXP-1), (DEC32_MIN_EXP-1))
 
+#define SUBNORMAL_MIN CHOOSE ( __DEC128_SUBNORMAL_MIN__, \
+                               __DEC64_SUBNORMAL_MIN__,  \
+                               __DEC32_SUBNORMAL_MIN__ )
+
+#define NORMAL_MAX CHOOSE ( __DEC128_MAX__, \
+                            __DEC64_MAX__,  \
+                            __DEC32_MAX__ )
+
+#define NORMAL_MAX_ULP CHOOSE ( 1e6111DL, \
+                                1e369DD,  \
+                                1e90DF )
+
 #define PRINTF_EXPR CHOOSE ("DDe", "De", "He")
 #define PRINTF_NEXPR CHOOSE ("DDf", "Df", "Hf")
 #define PRINTF_XEXPR CHOOSE (".33DDe", ".15De", ".7He")
@@ -145,6 +150,9 @@ static int noTests;             /* number of tests (without testing exceptions)
 static int verbose = 99;
 static int output_points = 1;   /* Should the single function results printed?  */
 
+static int max_aggr_ulp = 0;    /* Maximum ULP encountered across all tests */
+static const char *max_ulp_file = NULL;
+FLOAT max_allowed_ulp;
 
 /* Compare KEY (a string, with the name of a test or a function) with
    ULP (a pointer to a struct ulp_data structure), returning a value
@@ -184,32 +192,19 @@ find_test_ulps (const char *name)
 static FLOAT
 ulp (FLOAT value)
 {
-  FLOAT ulp;
+  value = FUNC (fabs) (value);
 
-  switch (fpclassify (value))
-    {
-      case FP_ZERO:
-        /* We compute the distance to the next FP which is the same as the
-           value of the smallest subnormal number. Previously we used
-           10^(-MANT_DIG) which is too large a value to be useful. Note that we
-           can't use ilogb(0), since that isn't a valid thing to do.  */
-        /* Fall through...  */
-      case FP_SUBNORMAL:
-        /* The next closest subnormal value is a constant distance away.  */
-        /* TODO: check it  */
-        ulp = FUNC(ldexp) (1.0DF, MIN_EXP - MANT_DIG);
-        break;
+  /* Sanity check. Values should always be finite. */
+  if (FUNC(isinf) (value) || FUNC(isnan) (value))
+    abort ();
 
-      case FP_NORMAL:
-        ulp = FUNC(ldexp) (1.0DF, FUNC(ilogb) (value) - (MANT_DIG) - 1);
-        break;
+  /* TODO: Subnormals aren't handled well by libdfp today. */
+  if (FUNC(fpclassify) (value) == FP_SUBNORMAL)
+    return SUBNORMAL_MIN;
+  if (value == NORMAL_MAX)
+    return NORMAL_MAX_ULP;
 
-      default:
-        /* It should never happen. */
-        abort ();
-        break;
-    }
-  return ulp;
+  return FUNC(nextafter) (value, DEC_INFINITY) - value;
 }
 
 static void
@@ -375,7 +370,6 @@ check_float (const char *test_name, FLOAT computed, FLOAT expected,
   if (extraflags & IGNORE_RESULT)
     goto out;
 
-  FLOAT max_ulp = find_test_ulps (test_name);
   if (issignaling (computed) && issignaling (expected))
     ok = 1;
   else if (issignaling (computed) || issignaling (expected))
@@ -397,8 +391,8 @@ check_float (const char *test_name, FLOAT computed, FLOAT expected,
       //if ((exceptions & IGNORE_ZERO_INF_SIGN) == 0
       if (signbit(computed) != signbit (expected))
         ok = 0;
-      //else if (ulps <= 0.5 || (ulps <= max_ulp && !ignore_max_ulp))
-      else if ((ulps <= 0.5DF) || (ulps <= max_ulp))
+      //else if (ulps <= 0.5 || (ulps <= max_allowed_ulp && !ignore_max_ulp))
+      else if ((ulps <= 0.5DF) || (ulps <= max_allowed_ulp))
         ok = 1;
       else
         {
@@ -406,6 +400,9 @@ check_float (const char *test_name, FLOAT computed, FLOAT expected,
           print_ulps (test_name, ulps);
         }
 
+      if (FUNC(ceil) (ulps) > max_aggr_ulp)
+        max_aggr_ulp = FUNC(ceil) (ulps);
+
     }
   if (print_screen (ok))
     {
@@ -422,7 +419,7 @@ check_float (const char *test_name, FLOAT computed, FLOAT expected,
           printf (" difference: % .20" PRINTF_EXPR "  %" PRINTF_XEXPR
                   "\n", diff, diff);
           printf (" ulp       : % .4" PRINTF_NEXPR "\n", ulps);
-          printf (" max.ulp   : % .4" PRINTF_NEXPR "\n", max_ulp);
+          printf (" max.ulp   : % .4" PRINTF_NEXPR "\n", max_allowed_ulp);
         }
     }
   update_stats (ok);
@@ -486,7 +483,7 @@ check_long (const char *test_name, long int computed, long int expected,
       printf ("Test: %s\n", test_name);
       printf ("Result:\n");
       printf (" is:         %ld\n", computed);
-      printf (" should be:  %lxd\n", expected);
+      printf (" should be:  %ld\n", expected);
     }
 
   update_stats (ok);
@@ -556,3 +553,35 @@ check_bool (const char *test_name, int computed, int expected, int extraflags)
  out:
   errno = 0;
 }
+
+/* Parse test options, if any. */
+static void scaffold_setup(int argn, char **argv, const char *test)
+{
+  int opt;
+
+  max_allowed_ulp = find_test_ulps (test);
+
+  while ( ((opt = getopt (argn, argv, "v:u:"))) && opt != -1)
+    switch (opt)
+      {
+	default: break;
+	case 'v': verbose = atoi (optarg); break;
+	case 'u': max_ulp_file = optarg; break;
+      }
+}
+
+/* Cleanup. Generate ulps file if requested */
+static void scaffold_teardown(void)
+{
+  if (max_ulp_file)
+    {
+      FILE *ulpf = fopen (max_ulp_file, "w");
+
+      if (!ulpf)
+        error(EXIT_FAILURE, 0, "fopen %s", max_ulp_file);
+      fprintf (ulpf, "%s %d\n",
+               CHOOSE("decimal128", "decimal64", "decimal32"),
+               max_aggr_ulp);
+      fclose (ulpf);
+    }
+}
