@@ -17,8 +17,8 @@
 
    You should have received a copy of the GNU Lesser General Public
    License version 2.1 along with the Decimal Floating Point C Library;
-   if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-   Suite 330, Boston, MA 02111-1307 USA.
+   if not, write to the Free Software Foundation, Inc., 51 Franklin
+   Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Please see libdfp/COPYING.txt for more information.  */
 
@@ -58,11 +58,6 @@
  * libdfp.  */
 #ifdef __DECIMAL_BID_FORMAT__
 # include "sysdeps/bid/bid-private.c"
-# ifndef HAVE_UINT128_T
-/* BID required int 128 bits and for system that does not define the type
-   the mini-gmp is required.  */
-#  include "libdecnumber/mini-gmp.c"
-# endif
 #else
 # include "sysdeps/dpd/dpd-private.c"
 #endif
@@ -108,6 +103,9 @@ d32_type d32[] =
   {__LINE__, 10.0000000E-95DF, "+1000000e-100", "%s"},
   /* Notice 1000000e-101 is the answer.  */
   {__LINE__, 10.0000000E-96DF,"+1000000e-101", "%s"},
+
+  /* __get_digits_d64 returns 0 for a NaN data.  */
+  {__LINE__, NAN, "+0000000e-101", "%s"},
 };
 static const int d32_s = sizeof (d32) / sizeof (d32[0]);
 
@@ -129,11 +127,12 @@ d64_type d64[] =
   {__LINE__, 0.0000000000000001E-365DD, "+1000000000000000e-396", "%s"},
   {__LINE__, 0.0000000000000001E-366DD, "+1000000000000000e-397", "%s"},
 
-  /* __get_digits_d64 returns +0000000000000001e-398 for a NaN data. */
-  {__LINE__, 0.0000100E-383DD, "+0000000000000001e-398", "%s"},
-  {__LINE__, 0.0001000E-383DD, "+0000000000000001e-398", "%s"},
-  {__LINE__, 0.0010000E-383DD, "+0000000000000001e-398", "%s"},
-  {__LINE__, 0.0100000E-383DD, "+0000000000000001e-398", "%s"},
+  /* Left justify is limited by the minimum exponent, this is why 1 is not the
+     first mantissa number.  */
+  {__LINE__, 0.0000100E-383DD, "+0000010000000000e-398", "%s"},
+  {__LINE__, 0.0001000E-383DD, "+0000100000000000e-398", "%s"},
+  {__LINE__, 0.0010000E-383DD, "+0001000000000000e-398", "%s"},
+  {__LINE__, 0.0100000E-383DD, "+0010000000000000e-398", "%s"},
 
   /* The minimum exponent we can left-justify if the mantissa is full.  */
   {__LINE__, 0.0000000000000001E-367DD, "+1000000000000000e-398", "%s"},
@@ -145,6 +144,12 @@ d64_type d64[] =
   {__LINE__, 0.1E-382DD, "+1000000000000000e-398", "%s"},
   /* Notice the 1 digit mantissa.  */
   {__LINE__, 1.E-383DD, "+1000000000000000e-398", "%s"},
+
+  /* Subnormal min test.  */
+  {__LINE__, 0.000000000000001E-383DD, "+0000000000000001e-398", "%s"},
+
+  /* __get_digits_d64 returns 0 for a NaN data.  */
+  {__LINE__, NAN, "+0000000000000000e-398", "%s"},
 };
 static const int d64_s = sizeof (d64) / sizeof (d64[0]);
 
@@ -169,12 +174,19 @@ d128_type d128[] =
 
   {__LINE__, 1E-6143DL, "+1000000000000000000000000000000000e-6176", "%s"},
   {__LINE__, 0.0000000000000001E-6127DL, "+1000000000000000000000000000000000e-6176", "%s"},
-  /* __get_digits_d128 returns +0000000000000000000000000000000001e-6176 for a NaN data. */
-  {__LINE__, 0.0000000000000001E-6140DL, "+0000000000000000000000000000000001e-6176", "%s"},
-  {__LINE__, 0.0000000000000100E-6143DL, "+0000000000000000000000000000000001e-6176", "%s"},
-  {__LINE__, 0.0000000000001000E-6143DL, "+0000000000000000000000000000000001e-6176", "%s"},
-  {__LINE__, 0.0000000000000001E-6143DL, "+0000000000000000000000000000000001e-6176", "%s"},
+
+  {__LINE__, 0.0000000000000001E-6140DL, "+0000000000000100000000000000000000e-6176", "%s"},
+  {__LINE__, 0.0000000000000100E-6143DL, "+0000000000000010000000000000000000e-6176", "%s"},
+  {__LINE__, 0.0000000000001000E-6143DL, "+0000000000000100000000000000000000e-6176", "%s"},
+  {__LINE__, 0.0000000000000001E-6143DL, "+0000000000000000100000000000000000e-6176", "%s"},
   {__LINE__, 0.0000000000000001E-6160DL, "+0000000000000000000000000000000001e-6176", "%s"},
+
+  /* Subnormal min test.  */
+  {__LINE__, 0.000000000000000000000000000000001E-6143DL, "+0000000000000000000000000000000001e-6176", "%s"},
+
+  /* __get_digits_d128 returns 0 for a NaN data.  */
+  {__LINE__, NAN, "+0000000000000000000000000000000000e-6176", "%s"},
+
 };
 static const int d128_s = sizeof (d128) / sizeof (d128[0]);
 
